@@ -1,17 +1,18 @@
 package File::Copy::Undoable;
 
+our $DATE = '2014-12-05'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any '$log';
 
 use Builtin::Logged qw(system);
+use File::MoreUtil qw(file_exists);
 use File::Trash::Undoable;
 #use PerlX::Maybe;
 use Proc::ChildError qw(explain_child_error);
-use SHARYANTO::File::Util qw(file_exists);
-
-our $VERSION = '0.05'; # VERSION
 
 our %SPEC;
 
@@ -161,7 +162,7 @@ File::Copy::Undoable - Copy file/directory using rsync, with undo support
 
 =head1 VERSION
 
-This document describes version 0.05 of File::Copy::Undoable (from Perl distribution File-Copy-Undoable), released on 2014-05-17.
+This document describes version 0.06 of File::Copy::Undoable (from Perl distribution File-Copy-Undoable), released on 2014-12-05.
 
 =head1 FUNCTIONS
 
@@ -260,6 +261,8 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+ (any)
+
 =head1 FAQ
 
 =head2 Why do you use rsync? Why not, say, File::Copy::Recursive?
@@ -281,7 +284,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Copy-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-File-Copy-Undoable>.
+Source repository is at L<https://github.com/perlancar/perl-File-Copy-Undoable>.
 
 =head1 BUGS
 
@@ -293,11 +296,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
